function convert_swash_output_subgrid(runfolder,savefolder,simno,tide,layers)
% This function will read through RAW SWASH .mat output for subgrid in 2 grids 
% to get water level, velocity, and domain components to be stored in a concatenated format.
% INPUT:
% runfolder: location where SWASH raw output is saved.
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% tide: tidal elevation put into SWASH simulation
% layers: number of layers in simulation
% OUTPUT:
% sim#_waterlevel.mat: waterlevel for full domain every second every layer
% sim#_velocity.mat: velocity for full domain every second every layer
% sim#_vorticity.mat: vorticity for full domain every second every layer
% sim#_domain.mat: full domain details

display('Start convert_swash_output_subgrid')

%% STEP 1: Saved Files
sname1 = [savefolder,'sim',simno,'_subgrid_waterlevel.mat'];
sname2 = [savefolder,'sim',simno,'_subgrid_vel_layer.mat'];
sname3 = [savefolder,'sim',simno,'_subgrid_domain.mat'];
sname4 = [savefolder,'sim',simno,'_subgrid_vorticity.mat'];


%% STEP 2a: Load files
subno = '';
count  = 0;

load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_domain.mat']);
duck_wat = load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_wat.mat']);
duck_u   = load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_uk.mat']);
duck_v   = load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_vk.mat']);
duck_z   = load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_zk.mat']);

%% STEP 2b: Dimensions
% File details
x = length(Xp(1,:)); % size x-dimension
y = length(Yp(:,1)); % size y-dimension

%% STEP 2c: Create List of File Names
% List of file names
ducknames_watlev = fieldnames(duck_wat); % Copy all file names from duck_wat
ducknames_u = fieldnames(duck_u); % Copy all file names from duck_uv
ducknames_v = fieldnames(duck_v);
ducknames_z = fieldnames(duck_z);

%% STEP 2d: Convert to 4D File
count = 0;
count2 = 0;
count3 = 0;
for i = 1:1:length(ducknames_watlev)-1
    count=count+1;
    eval(['wlev(:,:,',num2str(count),')=duck_wat.',char(ducknames_watlev{i}),';']);
    for j = 1:layers
        count2 = count2+1;
        eval(['vel_u(:,:,',num2str(j),',',num2str(count),')=duck_u.',char(ducknames_u{count2}),';']);
        eval(['vel_v(:,:,',num2str(j),',',num2str(count),')=duck_v.',char(ducknames_v{count2}),';']);
    end
    for k = 1:(layers+1)
        count3 = count3+1;
        eval(['zk(:,:,',num2str(k),',',num2str(count),')=duck_z.',char(ducknames_z{count3}),';']);
    end
end
clear i j

%% STEP 2e: Adjust tidal elevation for bathymetry
% To model tidal elevation, SWASH adjusts the bathymetry by shifting it up
% or down depending on the tidal elevation. We want the actually
% bathymetry, so this backs out the tide.
h = Botlev-tide;

%% Step 2f: Define where the beach is located
for i = 1:y
    for j = 1:x
        if Botlev(i,j)<tide;
            beach(i,j)=NaN;
        else beach(i,j)=1;
        end
    end
end
clear i j

%% STEP 2g: Calculate velocity
for k = 1:length(vel_v(1,1,1,:))
    for i = 1:length(vel_v(1,1,:,1))
        vort(:,:,i,k) = curl(Xp,Yp,vel_u(:,:,i,k),vel_v(:,:,i,k));
    end
end

clear k i

%% STEP 2h: Rename and Define File Format 
xp    = double(Xp);
yp   = double(Yp);
beach = double(beach);
h     = double(Botlev);
% t     = double((0:1:T)');
wlev  = double(wlev);
vel_u = double(vel_u);
vel_v = double(vel_v);
vort  = double(vort);
zk    = double(zk);
display('done with first section')

%% STEP 2i: Clear Variables
clearvars u v count count2 count3 i duck_uv duck_wat x y ii...
    ducknames_watlev ducknames_u ducknames_v ducknames_z Xp Yp Botlev...
    watlev vel_u vel_v vort zk

display('Ready to save.')

%% STEP 5: Save Variables

eval(['save -v7.3 ',sname1,' wlev'])
eval(['save -v7.3 ',sname2,' vel_u',' vel_v',' zk']);
eval(['save -v7.3 ',sname3,' xp',' yp',' h',' beach']);
eval(['save -v7.3 ',sname4,' vort'])

display('Done convert_swash_output_subgrid.')

end

