function interp_subgrid_eulerian_transect_alongshore(savefolder,frffolder,simno,tpos,tend,layers,tide,xloc,elev)
% This code will read through RAW SWASH .mat output to get water level, breaking and
% velocity components to be stored in a concatenated format
% INPUT:
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% tpos: start time for calculating time-averages parameters
% tend: end time for calculating time-averages parameters (normally length of simulation or 1 sec less)
% layers: number of layers in simulation
% tide: tidal elevation on frfdate
% elev: elevations which the layers will interpolate to
% OUTPUT:
% sim#_watlev_mean.mat: time-averaged waterlevel for subgrid
% sim#_zk_mean.mat: time-averaged layer boundary for subgrid
% sim#_velocity_mean.mat: time-averaged velocity per layer for subgrid
% sim#_vorticity_mean.mat: time-averaged vorticity per layer for subgrid
% sim#_cross-shore_param.mat: alongshore mean time-averaged parameters

%% STEP 1: Load .mat files for subgrid

display('Start calc_means_subgrid_eularian.m')

load([frffolder,'onshore_point_measurements.mat']);
load([savefolder,'sim',simno,'_subgrid_domain.mat']);
F1 = matfile([savefolder,'sim',simno,'_subgrid_vel_layer.mat']);
F2 = matfile([savefolder,'sim',simno,'_subgrid_waterlevel.mat']);
F3 = matfile([savefolder,'sim',simno,'_subgrid_vorticity.mat']);

%% STEP 2: Adjust domain and specificy dimensions
xfrf = fliplr(900-xp)+50;

x = length(xp(1,:)); % size x-dimension
y = length(yp(:,1)); % size y-dimension

%% STEP 3: Find the alongshore location to interpolate data

range               = 1;

x_loc_frf           = find(xfrf(1,:)==xloc); % find the grid location of the cross-shore specified locations
x_loc_check_frf     = xfrf(1,x_loc_frf) % this is a check to make sure you are saving the right location is chosen in the frf domain
xsim                = x-(x_loc_frf-1);  % find the grid location in the simulation format
xi                  = [xsim-range:xsim+range]; % pick locations around this for vorticity
x_loc_check_sim     = (900-xp(1,xi)+50) % this is another test to check if the right location is chosen in the simulation domain

% % Check to make sure above is correct output
% test        = squeeze(F1.vel_u(:,:,2,3600));
% fliptest    = fliplr(test);
% velsim      = test(:,xi);
% velfrf      = fliptest(:,x_loc_frf-1:x_loc_frf+1);
% dif         = fliplr(velsim)-velfrf
xpt     = xfrf(:,x_loc_frf-range:x_loc_frf+range);


%% STEP 4: Final File Names

sname1 = [savefolder,'elevation_interpolations/','sim',simno,'_vel_vort_alongshore_transects_x',num2str(xpt(1,1)),'to',num2str(xpt(1,end)),'m.mat']; % vel,vort,wlev,z,x,y
sname2 = [savefolder,'elevation_interpolations/','sim',simno,'_vel_vort_mean_alongshore_transects_x',num2str(xpt(1,1)),'to',num2str(xpt(1,end)),'m.mat'];
sname3 = [savefolder,'elevation_interpolations/','sim',simno,'_vel_vort_mean_alongshore_transect_x',num2str(xloc),'m.mat'];

%% STEP 5: Define time which velocity will be calculated for

vel_uk  = squeeze(F1.vel_u(:,xi,:,tpos:tend));
vel_vk  = squeeze(F1.vel_v(:,xi,:,tpos:tend));
zk      = squeeze(F1.zk(:,xi,:,tpos:tend));
wlev    = squeeze(F2.wlev(:,xi,tpos:tend));
% vort   = squeeze(F3.vort(:,:,:,tpos:tend));
time    = (tend-tpos)+1; % The length of all the strings are 1 longer than tpos-tend

%% STEP 6: Time to interp the data to specified layers
% Note that h is alwasy positive for bathymetry below mean sea level
% however, zk is negative for below sea level. This is the same coordinate
% system as elev (looking for negative values). 

tic
for j = 1:length(xi)
    for i = 1:y
        for l = 1:time
            for k = 1:layers
                zk_mid(i,j,k,l) = ((zk(i,j,k,l)+zk(i,j,k+1,l))/2);%+tide;
            end
            for m = 1:length(elev)
                if h(i,xi(j)) >= -elev(m)
                    temp_zk = squeeze(zk_mid(i,j,:,l));
                    temp_uk = squeeze(vel_uk(i,j,:,l));
                    temp_vk = squeeze(vel_vk(i,j,:,l));
                    test_if  = (nansum(temp_uk)+nansum(temp_vk))*nansum(~isnan(temp_zk));
                    if test_if == 0;
                        vel_uk_int(i,j,m,l) = NaN;
                        vel_vk_int(i,j,m,l) = NaN;
                    else
                        vel_uk_int(i,j,m,l) = interp1(temp_zk,temp_uk,elev(m),'linear','extrap');
                        vel_vk_int(i,j,m,l) = interp1(temp_zk,temp_vk,elev(m),'linear','extrap');
                        %                     vort_int(i,j,m,l)   = curl(xp(i,j),yp(i,j),vel_uk_int(i,j,m,l),vel_vk_int(i,j,m,l));
                    end
                elseif h(i,xi(j)) <= -elev(m)
                    vel_uk_int(i,j,m,l) = NaN;
                    vel_vk_int(i,j,m,l) = NaN;
                    %                     vort_int(i,j,m,l)   = NaN;
                end
            end
        end
    end
    display(num2str(xpt(1,j)))
end

for i = 1:time
   for j = 1:length(elev)
       vortk(:,:,j,i) = curl(xp(:,xi),yp(:,xi),vel_uk_int(:,:,j,i),vel_vk_int(:,:,j,i));
   end
end

clear zk_mid
eval(['save -v7.3 ',sname1,' vel_uk_int',' vel_vk_int',' vortk',' elev',' xpt',' xloc',' wlev']);

toc
display('Saved interpolated data.')
%% STEP 7: Calculate mean param
tic 

for i = 1:y
    for j = 1:length(xi)
         wlev_mean(i,j) = nanmean(squeeze(wlev(i,j,:)));
        for k = 1:length(elev)
            % mean
            vel_uk_mean(i,j,k) = nanmean(squeeze(vel_uk_int(i,j,k,:)));
            vel_vk_mean(i,j,k) = nanmean(squeeze(vel_vk_int(i,j,k,:)));
            vortk_mean(i,j,k) = nanmean(squeeze(vortk(i,j,k,:)));
            % standard deviation
            vel_uk_std(i,j,k) = nanstd(squeeze(vel_uk_int(i,j,k,:)));
            vel_vk_std(i,j,k) = nanstd(squeeze(vel_vk_int(i,j,k,:)));
            vortk_std(i,j,k) = nanstd(squeeze(vortk(i,j,k,:)));
        end
    end
end 

h_xloc = h(:,xi);

% wlev = wlev-tide;
% h = h-tide;
% elev = elev-tide;

eval(['save -v7.3 ',sname2,' vel_uk_mean',' vel_uk_std',' vel_vk_mean',' vel_vk_std',...
    ' vortk_mean',' vortk_std',' wlev_mean',' elev',' xpt',' xloc']);

display(['Done calculating and savubg mean over fulldomain. Domain is ',num2str(i),' by ',num2str(j),'.'])

clear i j k l
toc

%% STEP 8: Interpolate the velocity and vorticity to specific location

cent = length(xi)-(length(xi)-1)/2

wlev_yshore_mean = squeeze(wlev_mean(:,cent));
for i = 1:length(elev)
    % mean
    vel_uk_yshore_mean(:,i) = squeeze(vel_uk_mean(:,cent,i));%repmat(y_mean,length(yp(1,:))));
    vel_vk_yshore_mean(:,i) = squeeze(vel_vk_mean(:,cent,i));
    vortk_yshore_mean(:,i) = squeeze(vortk_mean(:,cent,i));
    % std
    vel_uk_yshore_std(:,i) = squeeze(vel_uk_std(:,cent,i));%repmat(y_mean,length(yp(1,:))));
    vel_vk_yshore_std(:,i) = squeeze(vel_vk_std(:,cent,i));
    vortk_yshore_std(:,i) = squeeze(vortk_std(:,cent,i));
end

    % bathy
    h_yshore = h(:,xsim);


display('ready to save the yshore mean files')

eval(['save -v7.3 ',sname3,' vel_uk_yshore_mean',' vel_vk_yshore_mean',...
    ' vel_uk_yshore_std',' vel_vk_yshore_std',' wlev_yshore_mean',...
    ' h_yshore',' vortk_yshore_mean',' vortk_yshore_std',' elev',' xloc'])

display('done')

end
