%%%%%%%%%%%%%%%%%%%% SWASH ANLYSIS MASTER MATLAB FILE %%%%%%%%%%%%%%%%%%%%%
% SWASH Analysis from raw output to post-processed data.
% These are a set of functions that are used to analyze SWASH output. 
% The following output for both the full domain and the subgrid will 
% be produced from this code:
% all output per second, snapshot of selected timeframe output,
% time-averaged domain prameters, and mean alongshore values.
%
% Section A: FULL DOMAIN
% STEP 1a: Process output and save all output for every second
% STEP 2a: Calculate mean params for domain and alongshore mean
% STEP 3a: Calculate Hsig
% STEP 4a: Select and save specific time range of data for "snapshot"
% STEP 5a: Seperately save offshore conditions in model run
% STEP 6a: PUV Analysis, saves directional spread and incidence angle
%
% Section B: SUBGRID
% STEP 1b: Process output and save all output for every second
% STEP 2b: Calculate mean params for domain and alongshore mean
% STEP 3b: Calculate Hsig
% STEP 4b: Select and save specific time range of data for "snapshot"

clc
clear all
close all
addpath(genpath('/data2/baker/SWASH/BATHYDuck15/codes/SWASH_analysis'));
addpath(genpath('/data2/baker/MTOOLS'));
frfpath  = '/data2/baker/Observations_BD15/data/';
% path = '/Users/cmbaker9/Documents/Research/SWASH/BATHYDuck/';
path  = '/data2/baker/SWASH/BATHYDuck15/';

%%%%%%%%%%%%%%%%%%%%%%%%% USER MODIFIABLE SECTION %%%%%%%%%%%%%%%%%%%%%%%%

% Simulation Details
dateran= '20_01'; % month of simulation
date   = '28-Oct-2015 00:00:00'; % date of forcing for simulation
simno  = '19';    % arbritrary number that helps name simulations related to date
time   = '7200'; % simulation time
layers = 5;      % number of layers in simulation
tide   = -0.320;  % tidal elevation in model run
tpos   = 3601;   % start time for calculating time-averages parameters
tend   = 7200;   % end time for calculating time-averages parameters (normally length of simulation or 1 sec less)
fdomno = 2;      % number of .mat files the full domain is seperated in
subno  = 6;      % number of .mat files the subgrid is seperated in
Tp     = 7.143;  % peak period of observations from 11 m
id     = 0; % if it is idealized, put 1 (different subregion). if not idealized put [].

% Consistant simulation folder name (same for run and data)
simfolder    = ['sim',simno,'_',date(1:2),'-',date(4:6),'-',date(8:11),'_',date(13:14),'00/'];
% simfolder = 'shore-normal_waves/';

% Run: simulation output location
subfolder = 'try4_final/';%'sim46_halfvar_hyak/';%[time,'_',num2str(layers),'_layers_PSlowvisc/'];
runfolder     = [path,'runs/',dateran,'/',simfolder,subfolder,''];

% Data: processed simulation output location
ssubfolder = [subfolder,''];%['sim',simno,'_',date(1:2),'-',date(4:6),'-',date(8:11),'_',date(13:14),'00/'];
%[time,'_',num2str(layers),'_layers/'];
savefolder = [path,'data/',simfolder,ssubfolder];
% savefolder = runfolder;

% Observations: location of processed observations to compare with swash simulations
frfsubfolder = '';
frffolder = [frfpath,frfsubfolder];

tic

%%%%%%%%%%%%%%%%%%%%%%%%%%% Copy INPUT File %%%%%%%%%%%%%%%%%%%%%%%%%%%%%

eval(['!mkdir ',path,'data/',simfolder]); % makes subfolder in data file
eval(['!mkdir ',path,'data/',simfolder,ssubfolder]); % makes subfolder in data file
eval(['!cp ',runfolder,'*.sws ',savefolder]); % copies *.sws to data folder

%%%%%%%%%%%%%%%%%%%%%%%% SECTION A: FULL DOMAIN %%%%%%%%%%%%%%%%%%%%%%%%

% STEP A1: Convert SWASH output to single .mat files
if fdomno     == 1;
    convert_swash_output_fulldomain_1grid(runfolder,savefolder,simno,tide)
elseif fdomno == 2;
    convert_swash_output_fulldomain_2grid(runfolder,savefolder,simno,tide)
end

% STEP A2: Calculate and save time-averaged and mean alongshore parameters
calc_means_fulldomain(savefolder,simno,tpos,tend)

% STEP A3: Estimate and save significant wave height
WL     = 256;    % Window length for calculated spectra, Steve=128, FRF=256
OL     = 128;    % Overlap length for calculated spectra, Steve=128*0.75, FRF = 128
estimate_Hsig_fulldomain(savefolder,simno,tpos,tend,WL,OL)

% STEP A3: Save snapshot of wlev and voriticity from spected range
SSpos  = 6400;   % start time for snapshot
SSend  = 6450;   % end time for snapshot
save_snapshots(savefolder,simno,SSpos,SSend)

% STEP A4: Seperately save offshore conditions in model run
WL     = 256;    % Window length for calculated spectra, Steve=128, FRF=256
OL     = 128;    % Overlap length for calculated spectra, Steve=128*0.75, FRF = 128
save_spectra(savefolder,frffolder,simno,tpos,tend,tide,WL,OL,id)

%%%%%%%%%%%%%%%%%%%%%%%% SECTION B: SUBGRID %%%%%%%%%%%%%%%%%%%%%%%%

convert_swash_output_subgrid(runfolder,savefolder,simno,subno,tide,layers)

% STEP B1: Convert SWASH output to single .mat files
if subno     == 1;
    convert_swash_output_subgrid_1grid(runfolder,savefolder,simno,tide,layers)
elseif subno == 2;
    convert_swash_output_subgrid_2grid(runfolder,savefolder,simno,tide,layers)
elseif subno == 3;
    convert_swash_output_subgrid_3grid(runfolder,savefolder,simno,tide,layers)
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% STEP B3: Estimate and save significant wave height
WL     = 256;    % Window length for calculated spectra, Steve=128, FRF=256
OL     = 128;    % Overlap length for calculated spectra, Steve=128*0.75, FRF = 128
estimate_Hsig_subgrid(savefolder,simno,tpos,tend,WL,OL)

% Let's start interpolating the elevations:
eval(['!mkdir ',path,'data/',simfolder,ssubfolder,'elevation_interpolations/']); % makes subfolder in data file
% interpolation option:
interp_opt = 2;
% 1 = interpolate for the whole domain at a specific resolution
% 2 = interpolate specific cross-shore locations

if interp_opt == 1
    % STEP B3: Option 1 - interpolate at a lower resolution acoross all domain
    elev = [-0.25; -0.5; -0.75; -1; -1.25; -1.5; -2; -3]; % less elevations as well!
    resx = 6; % 6 m resolution instead of 2 m because cross-shore res may not matter as much (?)
    resy = 2; % 2 m resolution in the alongshore to resolve VLK (Wave number spectra)
    interp_subgrid_vel(savefolder,frffolder,simno,tpos,tend,layers,tide,elev,resx,resy)
    
elseif interp_opt == 2
    % STEP B3: Option 2 - Interpolate the s-layer velocities to z-layer for specific locations
    elev = flipud([-5:0.1:-0.1]');
    
    % STEP B3a: For cross-shore transects
    xshore_transects = [10; 20; 80];
    for i = 1:length(xshore_transects)
        crossshore_array = xshore_transects(i); % specifies which cross-shore transect plotting
        interp_subgrid_eulerian_transect_crossshore_BDinst(savefolder,frffolder,simno,tpos,tend,layers,tide,crossshore_array,elev)
    end
    clear xshore_transects crossshore_array
    
    % STEP B3b: For cross-shore-transects
    if id == 1
        cshore_transects = [400; 440; 460; 480; 500; 520; 540; 560; 600; 800]; % idealized
    else
        cshore_transects = 270:10:990; % normal BD
    end
    for i = 1:length(cshore_transects)
        yloc = cshore_transects(i); % specifies which cross-shore transect plotting
        interp_subgrid_eulerian_transect_crossshore(savefolder,frffolder,simno,tpos,tend,layers,tide,yloc,elev)
    end
    clear cshore_transects yloc
    
    % STEP B3c: For alongshore-transects
    if id == 1
        ashore_transects = [350; 400; 450; 500; 550]; % idealized
    else
        ashore_transects = [100; 150; 174; 200; 226; 250; 300; 400; 500]; % not idealized
    end
    for i = 1:length(ashore_transects)
        xloc = ashore_transects(i); % specifies which cross-shore transect plotting
        interp_subgrid_eulerian_transect_alongshore(savefolder,frffolder,simno,tpos,tend,layers,tide,xloc,elev)
    end
    clear ashore_transects xloc
end

% STEP B4a: Coherence and phase BD instruments and then cross-shore
eval(['!mkdir ',savefolder,'rotary_spec/'])
xshore_transects    = [10; 20; 80];
num_in_squ          = 2; % out of 3 grids in the y-dim, which point is of interest
WL                  = 256;
OL                  = 128;
Fboundspec              = [0.004 0.006];
Fboundlp              = [0.003 0.007];
for m = 1:length(xshore_transects)
    BD = 1;
    xshore  = xshore_transects(m,:);    
    calc_coherence_phase_spectra_rotary_crossshore(savefolder,simno,num_in_squ,xshore,WL,OL,Tp,BD,Fboundspec,Fboundlp) 
end
if id == 1
    cshore_transects = [400; 440; 460; 480; 500; 520; 540; 560; 600; 800]; % idealized
else
    cshore_transects = 270:10:990; % normal BD
end

for i = 1:length(cshore_transects)
    BD = 0;
    xshore = cshore_transects(i); % specifies which cross-shore transect plotting
    calc_coherence_phase_spectra_rotary_crossshore(savefolder,simno,num_in_squ,xshore,WL,OL,Tp,BD,Fboundspec,Fboundlp)
end
clear cshore_transects yloc

% STEP B4b: Compute the drop in coherence and average in the alongshore
cshore_transects = 270:10:990;
bins = 3; % number of cm to avg over
calc_sz_coh_pha_drop(savefolder,simno,cshore_transects,bins)

% STEP B5: Calculate the alongshore wave number sprectra of vorticity
eval(['!mkdir ',savefolder,'alongshore_wavenumber_spectra'])
WL     = [];
OL     = [];
dt     = 60;     % length of time to compute spectra
Spectime = [(tpos+(dt/2)-1):1:(tend-(dt/2)-1)]-3600;

% STEP B5a: Compute for alongshore transects
ashore_transects = [100; 150; 174; 200; 226; 250; 300; 400; 500];
for i = 1:length(ashore_transects)
     xloc = ashore_transects(i); % specifies which cross-shore transect plotting
     calc_alongshore_wavenumber_spectra_vorticity_transects(savefolder,simno,Spectime,xloc,elev,tide,WL,OL)
end

% STEP B5b: Compute for depth averaged
dx      = 4; % dx to compute alongshore wavenumber to
if id == 1
	locx     = (320:dx:850)';
elseif id == 0
	locx 	= (100:dx:400)';
end
calc_alongshore_wavenumber_spectra_vorticity_depthavg(savefolder,simno,Spectime,locx,WL,OL,dt)
clear ashore_transects xloc

% STEP B5c: Compute at specific elevations
resx = 6;
% computing at specific elevations
calc_alongshore_wavenumber_spectra_vorticity_elev(savefolder,simno,Spectime,WL,OL,dt,resx)

%%%%%%%%%%%%%%%%%%%%%%%% SECTION C: FRF DATA %%%%%%%%%%%%%%%%%%%%%%%%

% STEP C: Save FRF measured data
save_FRF_conditions(savefolder,frffolder,simno,date)

toc
